import * as insuranceClaimServices from '@/services/api/InsuranceClaim';
import dayjs from 'dayjs';
import { useQuery } from '@tanstack/vue-query';

export function useInsuranceClaimCount() {
  const form = reactive({
    year: dayjs().year() + '',
    month: dayjs().month() + 1 + '',
    claimChannel: '',
  });

  const { data: claimCount } = useQuery({
    queryKey: ['insuranceClaimServices/getInsuranceClaimCount', form],
    queryFn: async () => {
      let res = await insuranceClaimServices.getInsuranceClaimCount(
        {
          year: form.year ? Number(form.year) : null,
          month: form.month ? Number(form.month) : null,
          claimChannel: form.claimChannel,
        },
        {
          showLoading: false,
        }
      );
      return res;
    },
    keepPreviousData: true,
  });

  function disabledYear(time: Date) {
    return dayjs(time).isAfter(dayjs(), 'year');
  }

  return {
    form,
    claimCount,
    disabledYear,
  };
}

type InsuranceClaimYearMonthCountCountOptions = {
  year: MaybeRef<number | string>;
};

export function useInsuranceClaimYearMonthCountCount({
  year,
}: InsuranceClaimYearMonthCountCountOptions) {
  const { data: claimYearMonthCountList, isLoading } = useQuery({
    queryKey: ['insuranceClaimServices/getInsuranceClaimYearMonthCountList', year],
    queryFn: async () => {
      let res = await insuranceClaimServices.getInsuranceClaimYearMonthCountList(
        {
          year: Number(unref(year)),
        },
        {
          showLoading: false,
        }
      );
      return res;
    },
    select(data) {
      return data.reverse();
    },
    placeholderData: () => [] as API.InsuranceClaimYearMonthCountListOutput[],
  });

  return {
    claimYearMonthCountList,
    isLoading,
  };
}
